#!/bin/bash
#############################################################################
# Purpose : Copy and apply Alfresco repo and/or share AMPs to overlay
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-09-30
# Package : alfresco-docker-utils-1.4.1
# Usage   : Run with name of project+instance and optional input paths
#############################################################################

function usage_error {
  echo -n "Usage: ${0##*/}"
  echo -n " <project>[:repo|share]"
  echo -n " [-f path_to_resource_folder]"
  echo -n " [-t path_to_tmp_folder]"
  echo -n " [-r]"
  echo
  exit 2
}

function deploy_amp {
  if [ ! -d "$RSRC_PATH/$PRJ_NAME/$INSTANCE-amps" ]; then
    mkdir -p $RSRC_PATH/$PRJ_NAME/$INSTANCE-amps
  fi
  if [ -n "$TMP_PATH" ]; then
    $SCRIPT_PATH/sudock.sh cp -v $TMP_PATH/alfresco-$PRJ_NAME-$INSTANCE-*.amp $RSRC_PATH/$PRJ_NAME/$INSTANCE-amps
  fi
  $SCRIPT_PATH/sudock.sh cp -v $RSRC_PATH/$PRJ_NAME/$INSTANCE-amps/alfresco-$PRJ_NAME-$INSTANCE-*.amp $ALF_HOME/tomcat-$INSTANCE/amps
  $SCRIPT_PATH/sudock.sh $ALF_HOME/bin/apply_amps.sh $INSTANCE -q
  [ "$RESTART" == "true" ] && docker restart $PRJ_NAME-alf-$INSTANCE
}

SCRIPT_PATH="$(dirname $(readlink -f $0))"
RSRC_PATH="$SCRIPT_PATH/resources"
PRJ_NAME="${1%%:*}"
INSTANCE="${1##*:}"
RESTART="false"
shift
while getopts f:t:r OPTION; do
  case ${OPTION} in
    f)
      RSRC_PATH="$OPTARG"
      ;;
    t)
      TMP_PATH="$OPTARG"
      ;;
    r)
      RESTART="true"
      ;;
    \?)
      usage_error
      ;;
  esac
done

[ -z "$PRJ_NAME" ] && usage_error

ALF_HOME="/opt/alfresco/$PRJ_NAME"
INSTANCES="repo share"

if [ "$PRJ_NAME" == "$INSTANCE" ]; then
  for INSTANCE in $INSTANCES; do
    deploy_amp
  done
else
  deploy_amp
fi
