#!/bin/bash
#############################################################################
# Purpose : Extract utility resource files from Alfresco installation package
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-09-18
# Package : alfresco-docker-utils-1.4.1
# Usage   : Run with name of package file and optional custom resource path
#############################################################################

function usage_error {
  echo "Usage: ${0##*/} <project> <alfresco_zip> [resource_dir]"
  exit 2
}

PRJ_NAME="$1"
ALF_PKG="$2"
[ -z "$PRJ_NAME" -o -z "$ALF_PKG" ] && usage_error
if [ ! -f "$ALF_PKG" ]; then
  echo "File '$ALF_PKG' not found."
  exit 2
fi

SCRIPT_PATH="$(dirname $(readlink -f $0))"
RSRC_PATH="${3:-$SCRIPT_PATH/resources}"
ALF_PKG_FILE="${ALF_PKG##*/}"
ALF_PKG_DIR="${ALF_PKG_FILE:0:-4}/"
unzip -t $ALF_PKG $ALF_PKG_DIR 2>&1 >/dev/null || ALF_PKG_DIR=""

echo "Extracting utility resource files from Alfresco installation package ..."

RESOURCES="bin/alfresco-mmt.jar web-server/webapps/*.war"
for RESOURCE in $RESOURCES; do
  unzip -jb $ALF_PKG ${ALF_PKG_DIR}$RESOURCE -d $RSRC_PATH/$PRJ_NAME
done
