#!/bin/bash
#############################################################################
# Purpose : Modified Alfresco script to create SSL trust
# Author  : Thore P. C. Kragelund, Redpill Linpro
# Date    : 2014-09-03
# Package : alfresco-docker-utils-1.4.1
#############################################################################

function usage_error {
  echo "Usage: ${0##*/} <project_name> [passphrase]"
  exit 2
}

PRJ_NAME="$1"
KEY_PASS="${2:-kT9X6oe68t}"

[ -z "$PRJ_NAME" ] && usage_error

# Alfresco installation directory
ALFRESCO_HOME=/opt/alfresco/$PRJ_NAME
# The directory containing the alfresco keystores, as referenced by keystoreFile and truststoreFile attributes in tomcat/conf/server.xml
ALFRESCO_KEYSTORE_HOME=$ALFRESCO_HOME/alf_data/keystore
# The repository server certificate subject name, as specified in tomcat/conf/tomcat-users.xml with roles="repository"
REPO_CERT_DNAME="CN=Alfresco Repository, OU=Unknown, O=Alfresco Software Ltd., L=Maidenhead, ST=UK, C=GB"
# The SOLR client certificate subject name, as specified in tomcat/conf/tomcat-users.xml with roles="repoclient"
SOLR_CLIENT_CERT_DNAME="CN=Alfresco Repository Client, OU=Unknown, O=Alfresco Software Ltd., L=Maidenhead, ST=UK, C=GB"
# The number of days before the certificate expires
CERTIFICATE_VALIDITY=36525
# Aliases
SSL_REPO="ssl.repo"
SSL_REPO_CLIENT="ssl.repo.client"

[ -d "$ALFRESCO_KEYSTORE_HOME" ] && mv $ALFRESCO_KEYSTORE_HOME $ALFRESCO_KEYSTORE_HOME.$(date +%Y%m%d%H%M%S)
mkdir -p "$ALFRESCO_KEYSTORE_HOME"

echo "Generate new self-signed certificates for the repository and solr ..."
keytool -genseckey -alias metadata -keypass $KEY_PASS -storepass $KEY_PASS -keystore $ALFRESCO_KEYSTORE_HOME/keystore -storetype JCEKS -keyalg DESede
keytool -genkeypair -keyalg RSA -dname "$REPO_CERT_DNAME" -validity $CERTIFICATE_VALIDITY -alias $SSL_REPO -keypass $KEY_PASS -keystore $ALFRESCO_KEYSTORE_HOME/ssl.keystore -storetype JCEKS -storepass $KEY_PASS
keytool -exportcert -alias $SSL_REPO -file $ALFRESCO_KEYSTORE_HOME/$SSL_REPO.crt -keystore $ALFRESCO_KEYSTORE_HOME/ssl.keystore -storetype JCEKS -storepass $KEY_PASS
keytool -genkeypair -keyalg RSA -dname "$SOLR_CLIENT_CERT_DNAME" -validity $CERTIFICATE_VALIDITY -alias $SSL_REPO_CLIENT -keypass $KEY_PASS -keystore $ALFRESCO_KEYSTORE_HOME/$SSL_REPO_CLIENT.keystore -storetype JCEKS -storepass $KEY_PASS
keytool -exportcert -alias $SSL_REPO_CLIENT -file $ALFRESCO_KEYSTORE_HOME/$SSL_REPO_CLIENT.crt -keystore $ALFRESCO_KEYSTORE_HOME/$SSL_REPO_CLIENT.keystore -storetype JCEKS -storepass $KEY_PASS

# Create trust relationship between repository and solr
keytool -importcert -noprompt -alias $SSL_REPO_CLIENT -file $ALFRESCO_KEYSTORE_HOME/$SSL_REPO_CLIENT.crt -keystore $ALFRESCO_KEYSTORE_HOME/ssl.truststore -storetype JCEKS -storepass $KEY_PASS
# Create trust relationship between repository and itself - used for searches
keytool -importcert -noprompt -alias $SSL_REPO -file $ALFRESCO_KEYSTORE_HOME/$SSL_REPO.crt -keystore $ALFRESCO_KEYSTORE_HOME/ssl.truststore -storetype JCEKS -storepass $KEY_PASS
# Create trust relationship between solr and repository
keytool -importcert -noprompt -alias $SSL_REPO -file $ALFRESCO_KEYSTORE_HOME/$SSL_REPO.crt -keystore $ALFRESCO_KEYSTORE_HOME/$SSL_REPO_CLIENT.truststore -storetype JCEKS -storepass $KEY_PASS
# Export repository keystore to pkcs12 format for browser compatibility
keytool -importkeystore -srckeystore $ALFRESCO_KEYSTORE_HOME/ssl.keystore -srcstorepass $KEY_PASS -srcstoretype JCEKS -srcalias $SSL_REPO -srckeypass $KEY_PASS -destkeystore $ALFRESCO_KEYSTORE_HOME/browser.p12 -deststoretype pkcs12 -deststorepass alfresco -destalias $SSL_REPO -destkeypass alfresco

cat <<EOF >$ALFRESCO_KEYSTORE_HOME/keystore-passwords.properties
aliases=metadata
keystore.password=$KEY_PASS
metadata.keyData=
metadata.algorithm=DESede
metadata.password=$KEY_PASS
EOF

cat <<EOF >$ALFRESCO_KEYSTORE_HOME/ssl-keystore-passwords.properties
aliases=ssl.alfresco.ca,$SSL_REPO
keystore.password=$KEY_PASS
ssl.repo.password=$KEY_PASS
ssl.alfresco.ca.password=$KEY_PASS
EOF

cat <<EOF >$ALFRESCO_KEYSTORE_HOME/ssl-truststore-passwords.properties 
aliases=alfresco.ca
keystore.password=$KEY_PASS
alfresco.ca.password=$KEY_PASS
EOF

echo "Certificate update complete"
